@@ -724,17 +724,20 @@ _getopt_internal (argc, argv, optstring, longopts, longind, long_only)
                 optarg = nameend + 1;
               else
                 {
-                  if (opterr)
-                   if (argv[optind - 1][1] == '-')
+                  if (opterr) {
+                   if (argv[optind - 1][1] == '-') {
                     /* --option */
                     fprintf (stderr,
                      _("%s: option `--%s' doesn't allow an argument\n"),
                      argv[0], pfound->name);
-                   else
+                   }
+                   else {
                     /* +option or -option */
                     fprintf (stderr,
                      _("%s: option `%c%s' doesn't allow an argument\n"),
                      argv[0], argv[optind - 1][0], pfound->name);
+                   }
+		  }
 
                   nextchar += strlen (nextchar);
 
